

# pysyncon ![](https://img.shields.io/badge/python-3.8+-blue.svg) ![build](https://github.com/sdfordham/pysyncon/actions/workflows/build.yml/badge.svg)

A python module for the synthetic control method that provides the same functionality as the R package [Synth](https://CRAN.R-project.org/package=Synth) and [augsynth](https://github.com/ebenmichael/augsynth) and eventually some other related methods (e.g. placebo tests).

## Installation
Install it from PyPI using pip:

````bash
python -m pip install pysyncon
````

## Usage

In the examples folder are notebooks reproducing the weights from:

- The Economic Costs of Conflict: A Case Study of the Basque Country, Alberto Abadie and Javier Gardeazabal; The American Economic Review Vol. 93, No. 1 (Mar., 2003), pp. 113-132.
- The worked example 'Prison construction and Black male incarceration' from the last chapter of 'Causal Inference: The Mixtape' by Scott Cunningham.
- Comparative Politics and the Synthetic Control Method, Alberto Abadie, Alexis Diamond and Jens Hainmueller; American Journal of Political Science Vol. 59, No. 2 (April 2015), pp. 495-510.
